diff --git a/cpp/src/db/meta/MySQLConnectionPool.h b/cpp/src/db/meta/MySQLConnectionPool.h
index 1b5345c762..9c6b751d1e 100644
--- a/cpp/src/db/meta/MySQLConnectionPool.h
+++ b/cpp/src/db/meta/MySQLConnectionPool.h
@@ -15,7 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#include "mysql++/mysql++.h"
+#include <mysql++/mysql++.h>
 
 #include <unistd.h>
 #include <atomic>
diff --git a/cpp/coverage.sh b/cpp/coverage.sh
index 84459fcc84..c0defe6f5a 100755
--- a/cpp/coverage.sh
+++ b/cpp/coverage.sh
@@ -70,11 +70,11 @@ fi
 for test in `ls ${DIR_UNITTEST}`; do
     echo $test
     case ${test} in
-        db_test)
-            # set run args for db_test
+        test_db)
+            # set run args for test_db
             args="mysql://${MYSQL_USER_NAME}:${MYSQL_PASSWORD}@${MYSQL_HOST}:${MYSQL_PORT}/${MYSQL_DB_NAME}"
             ;;
-        *_test)
+        *test_*)
             args=""
             ;;
     esac